@@ -87,7 +87,7 @@ private:
     QDBusPlatformMenu *m_menu;
     QDBusMenuAdaptor *m_menuAdaptor;
     QHash<quintptr, QDBusPlatformMenuItem *> m_menuItems;
-    QWindow *m_window = nullptr;
+    QPointer<QWindow> m_window;
     QString m_objectPath;
 
     QDBusPlatformMenuItem *menuItemForMenu(QPlatformMenu *menu);
